==> openjdk-21_21.0.10~4ea.orig.tar.xz: openjdk-21-21.0.10~4ea/test/micro/org/openjdk/bench/java/lang/reflect/Clazz.java <==
/*
 * Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.openjdk.bench.java.lang.reflect;

import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.util.concurrent.TimeUnit;

import org.openjdk.jmh.annotations.Benchmark;
import org.openjdk.jmh.annotations.BenchmarkMode;
import org.openjdk.jmh.annotations.Fork;
import org.openjdk.jmh.annotations.Measurement;
import org.openjdk.jmh.annotations.Mode;
import org.openjdk.jmh.annotations.OutputTimeUnit;
import org.openjdk.jmh.annotations.Warmup;

@BenchmarkMode(Mode.AverageTime)
@OutputTimeUnit(TimeUnit.NANOSECONDS)
@Warmup(iterations = 10, time = 1, timeUnit = TimeUnit.SECONDS)
@Measurement(iterations = 5, time = 2, timeUnit = TimeUnit.SECONDS)
@Fork(3)
public class Clazz {

    /**
     * Get constructor for this class through reflection
     *
     * @return
     * @throws NoSuchMethodException
     */
    @Benchmark
    public Constructor getConstructor() throws NoSuchMethodException {
        return Clazz.class.getConstructor();
    }

    /**
     * Get constructor for the String class through reflection, forcing full
     * security check
     *
     * @return
     * @throws NoSuchMethodException
     */
    @Benchmark
    public Constructor getConstructorDifferentClassLoader() throws NoSuchMethodException {
        return String.class.getConstructor();
    }

    /**
     * Get the toString method through reflection on Clazz
     *
     * @return
     */
    @Benchmark
    public Method getMethod() throws NoSuchMethodException {
        return Clazz.class.getMethod("toString");
    }

    /**
     * Get the toString method through reflection on String, forcing full
     * security check
     *
     * @return
     * @throws NoSuchMethodException
     */
    @Benchmark
    public Method getMethodDifferentClassLoader() throws NoSuchMethodException {
        return String.class.getMethod("toString");
    }
}

==> openjdk-26_26~28ea.orig.tar.xz: openjdk-26-26~28ea/test/micro/org/openjdk/bench/java/lang/reflect/Clazz.java <==
/*
 * Copyright (c) 2014, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.openjdk.bench.java.lang.reflect;

import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.util.concurrent.TimeUnit;

import org.openjdk.jmh.annotations.Benchmark;
import org.openjdk.jmh.annotations.BenchmarkMode;
import org.openjdk.jmh.annotations.Fork;
import org.openjdk.jmh.annotations.Measurement;
import org.openjdk.jmh.annotations.Mode;
import org.openjdk.jmh.annotations.OutputTimeUnit;
import org.openjdk.jmh.annotations.Warmup;
import org.openjdk.jmh.annotations.Scope;
import org.openjdk.jmh.annotations.State;

@BenchmarkMode(Mode.AverageTime)
@State(Scope.Benchmark)
@OutputTimeUnit(TimeUnit.NANOSECONDS)
@Warmup(iterations = 10, time = 1, timeUnit = TimeUnit.SECONDS)
@Measurement(iterations = 5, time = 2, timeUnit = TimeUnit.SECONDS)
@Fork(3)
public class Clazz {

    /**
     * Get constructor for this class through reflection
     *
     * @return
     * @throws NoSuchMethodException
     */
    @Benchmark
    public Constructor getConstructor() throws NoSuchMethodException {
        return Clazz.class.getConstructor();
    }

    /**
     * Get modifiers for this class through reflection
     *
     * @return
     * @throws NoSuchMethodException
     */
    @Benchmark
    public int getModifiers() {
        return Clazz.class.getModifiers();
    }

    Clazz[] clazzArray = new Clazz[1];
    @Benchmark
    public int getAppArrayModifiers() {
        return clazzArray.getClass().getModifiers();
    }

    static final Clazz[] clazzArrayFinal = new Clazz[1];
    @Benchmark
    public int getAppArrayModifiersFinal() {
        return clazzArrayFinal.getClass().getModifiers();
    }

    /**
     * Get modifiers for an primitive array class through reflection
     *
     * @return
     * @throws NoSuchMethodException
     */
    @Benchmark
    public int getArrayModifiers() {
        return int[].class.getModifiers();
    }


    /**
     * Get constructor for the String class through reflection, forcing full
     * security check
     *
     * @return
     * @throws NoSuchMethodException
     */
    @Benchmark
    public Constructor getConstructorDifferentClassLoader() throws NoSuchMethodException {
        return String.class.getConstructor();
    }

    /**
     * Get the toString method through reflection on Clazz
     *
     * @return
     */
    @Benchmark
    public Method getMethod() throws NoSuchMethodException {
        return Clazz.class.getMethod("toString");
    }

    /**
     * Get the toString method through reflection on String, forcing full
     * security check
     *
     * @return
     * @throws NoSuchMethodException
     */
    @Benchmark
    public Method getMethodDifferentClassLoader() throws NoSuchMethodException {
        return String.class.getMethod("toString");
    }
}
